<?php
/**
 * Plugin Name:     Holler Box Pro
 * Plugin URI:      http://hollerwp.com/pro
 * Description:     Premium features for the Holler Box plugin.
 * Version:         0.8.0
 * Author:          Scott Bolinger
 * Author URI:      http://hollerwp.com/pro
 * Text Domain:     hollerbox
 *
 * @author          Scott Bolinger
 * @copyright       Copyright (c) Scott Bolinger 2021
 *
 */


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

if( !class_exists( 'Holler_Box_Pro' ) ) {

    /**
     * Main Holler_Box class
     *
     * @since       0.1.0
     */
    class Holler_Box_Pro {

        /**
         * @var         Holler_Box $instance The one true Holler_Box
         * @since       0.1.0
         */
        private static $instance;


        /**
         * Get active instance
         *
         * @access      public
         * @since       0.1.0
         * @return      object self::$instance The one true Holler_Box
         */
        public static function instance() {
            if( !self::$instance ) {
                self::$instance = new Holler_Box_Pro();
                self::$instance->setup_constants();
                self::$instance->includes();
                self::$instance->load_textdomain();
                self::$instance->hooks();
            }

            return self::$instance;
        }


        /**
         * Setup plugin constants
         *
         * @access      private
         * @since       0.1.0
         * @return      void
         */
        private function setup_constants() {
            // Plugin version
            define( 'Holler_Box_Pro_VER', '0.8.0' );

            // Plugin path
            define( 'Holler_Box_Pro_DIR', plugin_dir_path( __FILE__ ) );

            // Plugin URL
            define( 'Holler_Box_Pro_URL', plugin_dir_url( __FILE__ ) );

            define('Holler_Box_Pro_File', __FILE__ );

            // this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
            define( 'HWP_PRO_STORE_URL', 'https://hollerwp.com' );

            // the name of your product. This is the title of your product in EDD and should match the download title in EDD exactly
            define( 'HWP_PRO_EDD_ID', 132 );
        }


        /**
         * Include necessary files
         *
         * @access      private
         * @since       0.1.0
         * @return      void
         */
        private function includes() {

            require_once Holler_Box_Pro_DIR . 'includes/class-holler-pro-functions.php';
            require_once Holler_Box_Pro_DIR . 'includes/class-holler-pro-ajax.php';

            if( is_admin() )
                require_once Holler_Box_Pro_DIR . 'includes/class-holler-pro-admin.php';

            if( !class_exists( 'EDD_SL_Plugin_Updater' ) )
                include( dirname( __FILE__ ) . '/includes/EDD_SL_Plugin_Updater.php' );
            
        }


        /**
         * Run action and filter hooks
         *
         * @access      private
         * @since       0.1.0
         * @return      void
         *
         *
         */
        private function hooks() {

        }


        /**
         * Internationalization
         *
         * @access      public
         * @since       0.1.0
         * @return      void
         */
        public function load_textdomain() {

            load_plugin_textdomain( 'hollerbox' );
            
        }

        /**
         * Holler Box Free Required admin notice
         *
         * @access      public
         * @since       0.1.0
         * @return      void
         */
        public static function hwp_required() {
            echo '<div id="message" class="error"><p>'. sprintf( __( '%1$s requires the Holler Box (free version) plugin to be installed/activated. Please install under Plugins => Add New => Search for Holler Box. %1$s has been deactivated.', 'hollerbox' ), '<b>Holler Box Pro</b> ' ) .'</p></div>';
            deactivate_plugins( plugin_basename( __FILE__ ), true );
        }

    }
} // End if class_exists check


/**
 * The main function responsible for returning the one true EDD_Metrics
 * instance to functions everywhere
 *
 * @since       0.1.0
 * @return      \EDD_Metrics The one true EDD_Metrics
 *
 */
function holler_box_pro_load() {

    // is main plugin active? If not, throw a notice and deactivate
    if ( !class_exists('Holler_Box') ) {
        add_action( 'all_admin_notices', array( 'Holler_Box_Pro', 'hwp_required' ) );
        return;
    }

    return Holler_Box_Pro::instance();
}
add_action( 'plugins_loaded', 'holler_box_pro_load' );


/**
 * The activation hook is called outside of the singleton because WordPress doesn't
 * register the call from within the class, since we are preferring the plugins_loaded
 * hook for compatibility, we also can't reference a function inside the plugin class
 * for the activation function. If you need an activation function, put it here.
 *
 * @since       0.1.0
 * @return      void
 */
function holler_box_pro_activation() {
    
}
// register_activation_hook( __FILE__, 'holler_box_pro_activation' );
